@@ -711,7 +711,7 @@ async def consumer(host: str,
                 LOG.info(f"Max iters reached: {max_iters}...returning...")
                 raise MaxIterationsException
 
-        except (KeyboardInterrupt, MaxIterationsException, EndOfFileException,
+        except (MaxIterationsException, EndOfFileException,
                 asyncio.IncompleteReadError) as err:
             LOG.info(f'Starting shutdown due to: {err.__class__.__name__}')
             await copy_writer.cleanup()
@@ -737,10 +737,11 @@ async def consumer(host: str,
             LOG.info('Exiting tacview-client!')
             return
 
-        except asyncpg.UniqueViolationError:
+        except asyncpg.UniqueViolationError as err:
             LOG.error("The file you are trying to process is already in the database! "
                         "To re-process it, delete all associated rows.")
-            sys.exit(1)
+            await sock.close(status='Error')
+            raise err
 
         except Exception as err:
             await sock.close(status='Error')
